print.frailtyIllnessDeath: Print a Short Summary of parameter estimates of a Weibull...

print.frailtyIllnessDeathR Documentation

Print a Short Summary of parameter estimates of a Weibull Illness-Death model with (or without) shared frailty between transitions.

Description

Prints a short summary of parameter estimates of a 'frailtyIllnessDeath' object

Usage

## S3 method for class 'frailtyIllnessDeath'
print(x,
...)

Arguments

x

the result of a call to the frailtyIllnessDeath function.

...

other unused arguments.

Value

Print the parameter estimates of the survival or hazard functions.

See Also

frailtyIllnessDeath


frailtypack documentation built on Aug. 25, 2026, 5:09 p.m.