Learn R Programming

frailtypack (version 2.2-9.5)

print.jointPenal: Print a Short Summary of parameter estimates of a joint frailty model

Description

Prints a short summary of parameter estimates of a joint frailty model, or more generally an object of class 'frailtyPenal' for joint frailty models.

Usage

## S3 method for class 'jointPenal':
print(x, digits = max(options()$digits - 4, 3), ...)

Arguments

x
the result of a call to the jointPenal function
digits
number of digits to print
...
other unusued arguments

Value

  • Print, separately for each type of event (recurrent and terminal), the parameter estimates of the survival or hazard functions.
  • nthe number of observations used in the fit.
  • n.groupsthe maximum number of groups used in the fit
  • n.eventsthe number of events observed in the fit
  • thetavariance of the common frailty term
  • alphathe coefficient associated with the frailty parameter terminal event hazard function
  • coefthe coefficients of the linear predictor, which multiply the columns of the model matrix.
  • varHthe variance matrix of theta and of the coefficients.
  • varHIHthe robust estimation of the variance matrix of theta and of the coefficients.
  • SE(H)the standard error of the estimaes deduced from the variance matrix of theta and of the coefficients.
  • SE(HIH)the standard error of the estimaes deduced from the robust estimation of the variance matrix of theta and of the coefficients.
  • pp-value

See Also

summary.jointPenal, frailtyPenal for Joint frailty models,plot.jointPenal

Examples

Run this code
# /*** Joint frailty model ***/
 

data(dataJoint)

  modJoint<-frailtyPenal(Surv(time.entry,time.end,status)~cluster(id)+var1+var2
                         +terminal(status.terminal),
                         formula.terminalEvent=~var1,
                         data=dataJoint,n.knots=7, Frailty=TRUE,
                         kappa1=1, kappa2=1, joint=TRUE, recurrentAG=TRUE)
    
 # It takes around 1 minute to converge.#

  print(modJoint)

Run the code above in your browser using DataLab