Learn R Programming

frailtypack (version 2.8.2)

print.longiPenal: Print a Summary of parameter estimates of a joint model for longitudinal data and a terminal event

Description

Prints a short summary of parameter estimates of a joint model for longitudinal data and a terminal event, an object inheriting from class 'longiPenal'.

Usage

## S3 method for class 'longiPenal':
print(x, digits = max(options()$digits - 4, 6), ...)

Arguments

x
an object inheriting from longiPenal class
digits
number of digits to print
...
other unused arguments

Value

  • Print, separately for each part of the model (longitudinal and terminal) the parameter estimates and details on the estimation.

See Also

longiPenal