Learn R Programming

frailtypack (version 2.8.2)

print.trivPenal: Print a Summary of parameter estimates of a joint model for longitudinal data, recurrent events and a terminal event

Description

Prints a short summary of parameter estimates of a joint model for longitudinal data, recurrent events and a terminal event, an object inheriting from class 'trivPenal'.

Usage

## S3 method for class 'trivPenal':
print(x, digits = max(options()$digits - 4, 6), ...)

Arguments

x
an object inheriting from trivPenal class
digits
number of digits to print
...
other unused arguments

Value

  • Print, separately for each part of the model (longitudinal, recurrent and terminal) the parameter estimates and details on the estimation.

See Also

trivPenal