Learn R Programming

frailtypack (version 2.2-9.5)

summary.jointPenal: summary of parameter estimates of a joint frailty model

Description

This function returns hazard rations (HR) and its confidence intervals

Usage

## S3 method for class 'jointPenal':
summary(object, level = 0.95, len = 6, d = 2, lab="hr", ...)

Arguments

object
output from a call to frailtyPenal for joint models
level
significance level of confidence interval. Default is 95%.
d
the desired number of digits after the decimal point. Default of 6 digits is used.
len
the total field width. Default is 6.
lab
label of printed results.
...
other unusued arguments.

Value

  • Prints HR and its confidence intervals for each covariate. Confidence level is allowed (level argument)

See Also

frailtyPenal for Joint frailty models, plot.jointPenal, print.jointPenal,

Examples

Run this code
data(dataJoint)

  modJoint<-frailtyPenal(Surv(time.entry,time.end,status)~cluster(id)+var1+var2
                         +terminal(status.terminal),
                         formula.terminalEvent=~var1,
                         data=dataJoint,n.knots=7,Frailty=TRUE,
                         kappa1=1, kappa2=1, joint=TRUE, recurrentAG=TRUE)

# It takes around 1 minute to converge  

  summary(modJoint)

Run the code above in your browser using DataLab