Learn R Programming

frailtypack (version 3.4.0)

summary.nestedPenal: summary of regression coefficient estimates of a nested frailty model

Description

This function returns hazard rations (HR) and its confidence intervals for each regression coefficient.

Usage

# S3 method for nestedPenal
summary(object, level = 0.95, len = 6, d = 2,
lab="hr", ...)

Arguments

object

output from a call to nestedPenal.

level

significance level of confidence interval. Default is 95%.

len

the total field width. Default is 6.

d

the desired number of digits after the decimal point. Default of 6 digits is used.

lab

label of printed results.

…

other unused arguments.

Value

Prints HR and its confidence intervals for each regression coefficient. Confidence level is allowed (level argument).

See Also

frailtyPenal

Examples

Run this code
# NOT RUN {

# }
# NOT RUN {
data(dataNested)

modNested <- frailtyPenal(Surv(t1,t2,event)~cluster(group)+
subcluster(subgroup)+cov1+cov2,data=dataNested,
n.knots=8,kappa=c(50000,50000),hazard="Splines")

#- It takes 90 minutes to converge (depends on processor)

summary(modNested)

# }
# NOT RUN {

# }

Run the code above in your browser using DataLab