Arguments
formula
a formula object, with the response on the left of a $\texttildelow$
operator, and the terms on the right. The response must be a
survival object as returned by the 'Surv' function like in survival package.
formula.terminalEvent
a formula object, only requires terms on the right to indicate which variables are modelling the terminal event.
data
a 'data.frame' in which to interpret the variables named in the 'formula' and 'formula.terminalEvent'.
Frailty
Logical value. Is model with frailties fitted? If so, variance of frailty parameter is estimated. The default is FALSE
joint
Logical value. Is joint model fitted? If so, 'formula.terminalEvent' is required. The default is FALSE
recurrentAG
Logical value. Is Andersen-Gill model fitted? If so indicates that recurrent event times with the
counting process approach of Andersen and Gill is used. This formulation can be used for dealing with
time-dependent cov
cross.validation
Logical value. Is cross validation procedure used for estimating smoothing parameter in the penalized likelihood estimation?
If so a search of the smoothing parameter using cross validation is done, with kappa1 as the seed.
n.knots
integer giving the number of knots to use. Value required in the penalized likelihood estimation.
It corresponds to the (n.knots+2) splines functions for the approximation of the hazard or the survival functions.
Number o
kappa1
positive smoothing parameter in the penalized likelihood estimation. The coefficient kappa of the integral of the squared
second derivative of hazard function in the fit (penalized log likelihood). To obtain a good
value for
kappa2
positive smoothing parameter in the penalized likelihood estimation for the terminal event rate. To obtain a good value
for kappa2, a solution is to fit the corresponding Cox model using cross-validation (See cross.validation)
maxit
maximum number of iterations for the Marquardt algorithm. Default is 350
hazard
Type of hazard functions: "Splines" for semi-parametrical hazard functions with the penalized likelihood estimation,
"Piecewise-per" for piecewise constant hazard function using percentile, "Piecewise-equi" for piecewise constant
nb.int1
Number of intervals (between 1 and 20) for the recurrent parametrical hazard functions ("Piecewise-per", "Piecewise-equi").
nb.int2
Number of intervals (between 1 and 20) for the death parametrical hazard functions ("Piecewise-per", "Piecewise-equi").
intcens
Not implemented for joint frailty model.
synopsis
frailtyPenal(formula, formula.terminalEvent, data, Frailty = FALSE,
joint = FALSE, recurrentAG = FALSE, cross.validation =
FALSE, n.knots, kappa1, kappa2, maxit = 350,hazard = "Splines",nb.int1,nb.int2
intcens = FALSE)